@@ -1,3 +1,4 @@
+import time
 import re
 import errno
 import uasyncio as asyncio
@@ -78,16 +79,17 @@ class WebApp:
 
     def _handle(self, reader, writer):
         request_line = yield from reader.readline()
+        req = HTTPRequest()
         # TODO: bytes vs str
         request_line = request_line.decode()
         method, path, proto = request_line.split()
+        print('%.3f %s %s "%s %s"' % (time.time(), req, writer, method, path))
         path = path.split("?", 1)
         qs = ""
         if len(path) > 1:
             qs = path[1]
         path = path[0]
         headers = {}
-        req = HTTPRequest()
         while True:
             l = yield from reader.readline()
             # TODO: bytes vs str
@@ -96,9 +98,9 @@ class WebApp:
                 break
             k, v = l.split(":", 1)
             headers[k] = v.strip()
-        print("================")
-        print(req, writer)
-        print(req, (method, path, qs, proto), headers)
+#        print("================")
+#        print(req, writer)
+#        print(req, (method, path, qs, proto), headers)
 
         # Find which mounted subapp (if any) should handle this request
         app = self
@@ -148,9 +150,10 @@ class WebApp:
         else:
             yield from start_response(writer, status="404")
             yield from writer.awrite("404\r\n")
-        print(req, "After response write")
+        #print(req, "After response write")
         yield from writer.close()
-        print(req, "Finished processing request")
+        if __debug__ and self.debug > 1:
+            print(req, "Finished processing request")
 
     def mount(self, url, app):
         "Mount a sub-app at the url of current app."
@@ -190,6 +193,7 @@ class WebApp:
         self.inited = True
 
     def run(self, host="127.0.0.1", port=8081, debug=False, lazy_init=False):
+        self.debug = int(debug)
         self.init()
         if not lazy_init:
             for app in self.mounts:
